@@ -50,4 +50,8 @@ class SimpleQueue:
         return self._queue.qsize()
 
     def dict_size(self):
-        return len(self._dict)
\ No newline at end of file
+        return len(self._dict)
+
+    def clear(self):
+        self._queue.clear()
+        self._dict.clear()
\ No newline at end of file
