@@ -75,4 +75,13 @@ class UniqueKeyQueue:
         return len(self._queue_set)
 
     def dict_size(self):
-        return len(self._dict)
\ No newline at end of file
+        return len(self._dict)
+
+    def clear(self):
+        try:
+            lock.acquire()
+            self._queue.clear()
+            self._queue_set.clear()
+            self._dict.clear()
+        finally:
+            lock.release()
\ No newline at end of file
